==> assertj-build-3.25.3.tar.gz: assertj-assertj-build-3.25.3/assertj-core/src/test/java/org/assertj/core/api/charsequence/CharSequenceAssert_doesNotContainPattern_String_Test.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2024 the original author or authors.
 */
package org.assertj.core.api.charsequence;

import static org.assertj.core.test.TestData.matchAnything;
import static org.mockito.Mockito.verify;

import org.assertj.core.api.CharSequenceAssert;
import org.assertj.core.api.CharSequenceAssertBaseTest;
import org.junit.jupiter.api.BeforeAll;

/**
 * Tests for <code>{@link CharSequenceAssert#doesNotContainPattern(CharSequence)}</code>.
 */
class CharSequenceAssert_doesNotContainPattern_String_Test extends CharSequenceAssertBaseTest {

  private static CharSequence regex;

  @BeforeAll
  static void setUpOnce() {
    regex = matchAnything().pattern();
  }

  @Override
  protected CharSequenceAssert invoke_api_method() {
    return assertions.doesNotContainPattern(regex);
  }

  @Override
  protected void verify_internal_effects() {
    verify(strings).assertDoesNotContainPattern(getInfo(assertions), getActual(assertions), regex);
  }
}

==> assertj-build-3.27.6.tar.gz: assertj-assertj-build-3.27.6/assertj-core/src/test/java/org/assertj/core/api/charsequence/CharSequenceAssert_doesNotContainPattern_String_Test.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2025 the original author or authors.
 */
package org.assertj.core.api.charsequence;

import static org.assertj.core.testkit.TestData.matchAnything;
import static org.mockito.Mockito.verify;

import org.assertj.core.api.CharSequenceAssert;
import org.assertj.core.api.CharSequenceAssertBaseTest;
import org.junit.jupiter.api.BeforeAll;

/**
 * Tests for <code>{@link CharSequenceAssert#doesNotContainPattern(CharSequence)}</code>.
 */
class CharSequenceAssert_doesNotContainPattern_String_Test extends CharSequenceAssertBaseTest {

  private static CharSequence regex;

  @BeforeAll
  static void setUpOnce() {
    regex = matchAnything().pattern();
  }

  @Override
  protected CharSequenceAssert invoke_api_method() {
    return assertions.doesNotContainPattern(regex);
  }

  @Override
  protected void verify_internal_effects() {
    verify(strings).assertDoesNotContainPattern(getInfo(assertions), getActual(assertions), regex);
  }
}
